diff --git a/src/bin/pg_dump/pg_dump_sort.c b/src/bin/pg_dump/pg_dump_sort.c
index 6676baf..84f68c9 100644
--- a/src/bin/pg_dump/pg_dump_sort.c
+++ b/src/bin/pg_dump/pg_dump_sort.c
@@ -163,7 +163,26 @@ DOTypeNameCompare(const void *p1, const void *p2)
 	if (cmpval != 0)
 		return cmpval;
 
-	/* Probably shouldn't get here, but if we do, sort by OID */
+	/* To have a stable sort order, break ties for some object types */
+    if (obj1->objType == DO_FUNC || obj1->objType == DO_AGG)
+	{
+		FuncInfo *fobj1 = *(FuncInfo **) p1;
+		FuncInfo *fobj2 = *(FuncInfo **) p2;
+		int i;
+
+		cmpval = fobj1->nargs - fobj2->nargs;
+		if (cmpval != 0)
+			return cmpval;
+
+		for (i = 0; i < fobj1->nargs; i++)
+		{
+			cmpval = oidcmp(fobj1->argtypes[i], fobj2->argtypes[i]);
+			if (cmpval != 0)
+				return cmpval;
+		}
+	}
+
+	/* Usually shouldn't get here, but if we do, sort by OID */
 	return oidcmp(obj1->catId.oid, obj2->catId.oid);
 }
 
